package de.intevation.flys.client.client.services;

import com.google.gwt.user.client.rpc.RemoteService;
import com.google.gwt.user.client.rpc.RemoteServiceRelativePath;

import de.intevation.flys.client.shared.exceptions.ServerException;
import de.intevation.flys.client.shared.model.Artifact;
import de.intevation.flys.client.shared.model.Collection;

import de.intevation.flys.client.shared.model.Recommendation;

/**
 * This interface provides artifact specific services as CREATE, DESCRIBE, FEED,
 * ADVANCE and OUT.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
@RemoteServiceRelativePath("artifact")
public interface ArtifactService extends RemoteService {

    /**
     * This method creates a new artifact based on the given <i>factory</i>.
     *
     * @param serverUrl The url of the artifact server.
     * @param locale The locale used for the request.
     * @param factory The factory that should be used for the artifact creation.
     *
     * @return the new artifact.
     */
    public Artifact create(
        String         locale,
        String         factory,
        Recommendation recommendation
    ) throws ServerException;

    /**
     * Create a new GaugeDischageCurveArtifact
     *
     * @param collection the collection to add the artifact to
     * @param river      the river
     * @param gaugeref   reference id of the gauge
     */
    public Artifact createGaugeDischargeCurverArtifact(
            Collection collection,
            String locale,
            String river,
            Long   gaugeref
    ) throws ServerException;
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
